@@ -1,8 +1,6 @@
-from flask_sketch.utils import (
-    Sketch,
-    pjoin,
-)
+from flask_sketch.utils import Sketch, pjoin
 from flask_sketch import templates
+from uuid import uuid4
 
 
 def handle_caching(sketch: Sketch):
@@ -98,6 +96,24 @@ def handle_admin(sketch: Sketch):
             pjoin(sketch.app_folder, "ext", "admin", "__init__.py",),
         )
 
+    if sketch.auth_framework == "none":
+        sketch.add_requirements("flask-basicauth")
+        sketch.add_extensions("admin.basic_auth")
+        sketch.secrets["default"]["BASIC_AUTH_USERNAME"] = "admin"
+        sketch.secrets["default"]["BASIC_AUTH_PASSWORD"] = str(uuid4())
+
+        sketch.write_template(
+            "ext_basicauth_tpl",
+            templates.ext.admin,
+            pjoin(sketch.app_folder, "ext", "admin", "basic_auth.py",),
+        )
+
+        sketch.write_template(
+            "ext_admin_basicauth_tpl",
+            templates.ext.admin,
+            pjoin(sketch.app_folder, "ext", "admin", "__init__.py",),
+        )
+
 
 def handle_debugtoolbar(sketch: Sketch):
     sketch.add_requirements("flask-debugtoolbar", dev=True)
