@@ -1,24 +1,9 @@
 commom_questions = [
     {
-        "type": "list",
-        "message": "Select the type of your project",
-        "name": "application_type",
-        "choices": [
-            {"name": "Web Only (no API)", "value": "web_only"},
-            {
-                "name": "API Only (no frontend)",
-                "value": "api_only",
-                "disabled": "Not yet supported",
-            },
-            {
-                "name": "Web and API",
-                "value": "web_and_api",
-                "disabled": "Soon will be supported.",
-            },
-        ],
-        "validate": lambda answer: "You must choose at least one topping."
-        if len(answer) == 0
-        else True,
+        "type": "confirm",
+        "name": "have_api",
+        "message": "This project have an API?",
+        "default": False,
     },
     {
         "type": "list",
